@@ -28,7 +28,7 @@
 #' @param http The HTTP method to use, one of "get" or "post". Default: "get".
 #' Use \code{http="post"} with large queries. Queries with > 300 records
 #' use "post" automatically because "get" would fail
-#' @param ... Curl options passed on to \code{\link[httr]{GET}}
+#' @param ... Curl options passed on to \code{\link[crul]{HttpClient}}
 #' @param cap_first (logical) For each name, fix so that the first name part is
 #' capitalized, while others are not. This web service is sensitive to
 #' capitalization, so you'll get different results depending on capitalization.
@@ -41,6 +41,7 @@
 #' @return A data.frame with one attribute \code{not_known}: a character
 #' vector of taxa unknown to the Global Names Index. Access like
 #' \code{attr(output, "not_known")}, or \code{attributes(output)$not_known}.
+#' 
 #' Columns of the output data.frame:
 #' \itemize{
 #'  \item user_supplied_name (character) - the name you passed in to the
@@ -74,6 +75,11 @@
 #' }
 #' Note that names (i.e. rows) are dropped that are NA, are zero length
 #' strings, are not character vectors, or are not found by the API.
+#' 
+#' @section preferred_data_sources:
+#' If \code{preferred_data_sources} is used, only the preferred data 
+#' is returned - if it has any results.
+#' 
 #' @seealso \code{\link[taxize]{gnr_datasources}} \code{\link{tnrs}}
 #' @keywords resolve names taxonomy
 #' @references \url{http://gnrd.globalnames.org/api}
@@ -119,7 +125,7 @@ gnr_resolve <- function(names, data_source_ids = NULL, resolve_once = FALSE,
 
   fields <- match.arg(fields, c("minimal", "all"))
   http <- match.arg(http, c("get", "post"))
-  num = NULL
+  num <- NULL
   url <- "http://resolver.globalnames.org/name_resolvers.json"
   # clean out zero length strings
   names <- Filter(function(x) nzchar(x) && !is.na(x) && is.character(x), names)
@@ -142,10 +148,11 @@ gnr_resolve <- function(names, data_source_ids = NULL, resolve_once = FALSE,
             with_canonical_ranks = cv(with_canonical_ranks)))
   args <- argsnull(args)
 
+  cli <- crul::HttpClient$new(url = url, opts = list(...))
   if (http == 'get') {
-    tmp <- GET(url, query = args, ...)
-    warn_for_status(tmp)
-    tmp2 <- con_utf8(tmp)
+    tmp <- cli$get(query = args)
+    tmp$raise_for_status()
+    tmp2 <- tmp$parse("UTF-8")
     dat <- jsonlite::fromJSON(tmp2, FALSE)$data
   } else {
     args <- args[!names(args) %in% "names"]
@@ -158,10 +165,9 @@ gnr_resolve <- function(names, data_source_ids = NULL, resolve_once = FALSE,
       file <- tempfile(fileext = ".txt")
       write.table(tt, file = file, row.names = FALSE,
                   col.names = FALSE, quote = FALSE)
-      ss <- POST(url, query = args,
-                 body = list(file = upload_file(path = file)), ...)
-      warn_for_status(ss)
-      ss <- con_utf8(ss)
+      tmp <- cli$post(query = args, body = list(file = crul::upload(file)))
+      tmp$raise_for_status()
+      ss <- tmp$parse("UTF-8")
       datbits[[i]] <- jsonlite::fromJSON(ss, FALSE)$data
     }
 
@@ -171,10 +177,12 @@ gnr_resolve <- function(names, data_source_ids = NULL, resolve_once = FALSE,
   # add original name supplied by user
   dat <- Map(function(x,y) c(original_name = y, x), dat, orig_names)
 
+  to_get <- if (is.null(preferred_data_sources)) "results" else "preferred_results"
+
   data_ <-
     lapply(dat, function(y) {
-      if (!is.null(unlist(y$results))) {
-        res <- lapply(y$results, function(x) {
+      if (!is.null(unlist(y[[to_get]]))) {
+        res <- lapply(y[[to_get]], function(x) {
           take_fields <- switch(fields,
             minimal = c("name_string", "data_source_title","score",
                         "canonical_form"),
@@ -191,7 +199,6 @@ gnr_resolve <- function(names, data_source_ids = NULL, resolve_once = FALSE,
     })
   not_known <- Filter(function(x) is.null(x[[2]]), data_)
   not_known <- sapply(not_known, function(x) x[[1]]$original_name)
-  # vapply(not_known, "[[", "", 1)
   data_ <- Filter(function(x) !is.null(x[[2]]), data_)
 
   # check for empty data object
@@ -201,74 +208,31 @@ gnr_resolve <- function(names, data_source_ids = NULL, resolve_once = FALSE,
   if (inherits(drill, "simpleError")) {
     out <- data.frame(NULL)
   } else {
-    if (is.null(preferred_data_sources)) {
-      data_2 <- ldply(data_, function(x)
-        data.frame(x[[1]], ldply( if (length(x[[2]]) == 0) {
-        list(data.frame(name_string = "", data_source_title = "", score = NaN,
-                        canonical_form = ""))
-      } else {
-        x[[2]]
-      }), stringsAsFactors = FALSE))
-      names(data_2)[names(data_2) %in% to_rename] <-
-        c("user_supplied_name", "submitted_name",
-          "matched_name", "matched_name2")
-      data_2$matched_name <- as.character(data_2$matched_name)
-      data_2$data_source_title <- as.character(data_2$data_source_title)
-      data_2$matched_name2 <- as.character(data_2$matched_name2)
-
-      if (canonical) {
-        data_2 <- data_2[ , !names(data_2) %in% "matched_name"]
-      } else {
-        data_2 <- data_2[ , !names(data_2) %in% "matched_name2"]
-      }
-      # canonical = TRUE, may result into duplicates
-      out <- unique(data_2)
+    data_2 <- ldply(data_, function(x)
+      data.frame(x[[1]], ldply( if (length(x[[2]]) == 0) {
+      list(data.frame(name_string = "", data_source_title = "", score = NaN,
+                      canonical_form = ""))
     } else {
-      data_preferred <-
-        lapply(dat, function(y) {
-          if (!is.null(unlist(y$preferred_results))) {
-            res <- lapply(y$preferred_results, function(x) {
-              data.frame(x[c("name_string", "data_source_title", "score",
-                             "canonical_form")], stringsAsFactors = FALSE)
-            })
-          } else {
-            res <- NULL
-          }
-          list(y[c("original_name", "supplied_name_string")], res)
-        })
-      data_2_preferred <- ldply(data_preferred, function(x)
-        data.frame(x[[1]], ldply(if (length(x[[2]]) == 0) {
-        list(data.frame(name_string = "", data_source_title = "", score = NaN,
-                        canonical_form = ""))
-      } else {
-        x[[2]]
-      }), stringsAsFactors = FALSE))
-      if (NROW(data_2_preferred) == 0) {
-        out <- data_2_preferred
-      } else {
-        names(data_2_preferred)[names(data_2_preferred) %in% to_rename] <-
-          c("user_supplied_name", "submitted_name",
-            "matched_name", "matched_name2")
-        data_2_preferred$matched_name <-
-          as.character(data_2_preferred$matched_name)
-        data_2_preferred$data_source_title <-
-          as.character(data_2_preferred$data_source_title)
-        data_2_preferred$matched_name2 <-
-          as.character(data_2_preferred$matched_name2)
+      x[[2]]
+    }), stringsAsFactors = FALSE))
+    names(data_2)[names(data_2) %in% to_rename] <-
+      c("user_supplied_name", "submitted_name",
+        "matched_name", "matched_name2")
+    data_2$matched_name <- as.character(data_2$matched_name)
+    data_2$data_source_title <- as.character(data_2$data_source_title)
+    data_2$matched_name2 <- as.character(data_2$matched_name2)
 
-        if (canonical) {
-          out <-
-            data_2_preferred[ , !names(data_2_preferred) %in% "matched_name"]
-        } else {
-          out <-
-            data_2_preferred[ , !names(data_2_preferred) %in% "matched_name2"]
-        }
-      }
+    if (canonical) {
+      data_2 <- data_2[ , !names(data_2) %in% "matched_name"]
+    } else {
+      data_2 <- data_2[ , !names(data_2) %in% "matched_name2"]
     }
+    # canonical = TRUE, may result into duplicates
+    out <- unique(data_2)
   }
 
   row.names(out) <- NULL
-  structure(out, not_known = not_known)
+  structure(tibble::as_tibble(out), not_known = not_known)
 }
 
 cv <- function(x) {
