@@ -1,10 +1,13 @@
 # tests for eol_pages fxn in taxize
 context("eol_pages")
 
-pageid <- suppressMessages(eol_search('Pomatomus'))$pageid[1]
-pageid2 <- suppressMessages(eol_search('Helianthus'))$pageid[1]
 
-test_that("eol_pages returns the correct value", {
+test_that("eol_pages returns the correct value and classes", {
+  skip_on_cran()
+
+  pageid <- suppressMessages(eol_search('Pomatomus'))$pageid[1]
+  pageid2 <- suppressMessages(eol_search('Helianthus'))$pageid[1]
+
   aa <- suppressMessages(eol_pages(taxonconceptID = pageid))
 
   expect_is(aa, "list")
@@ -16,8 +19,6 @@ test_that("eol_pages returns the correct value", {
 	expect_is(bb, "list")
 	expect_is(bb$scinames, "data.frame")
 	expect_is(bb$syns, "character")
-})
 
-test_that("eol_pages returns the correct class", {
 	expect_is(suppressMessages(eol_pages(taxonconceptID=pageid))$scinames, "data.frame")
 })
