@@ -4,7 +4,7 @@ context("gni_details")
 test_that("gni_details returns the correct value", {
   skip_on_cran()
 
-	expect_that(as.character(gni_details(id = 17802847)[,3]), matches("none"))
+  expect_match(as.character(gni_details(id = 17802847)[,3]), "none")
 })
 
 test_that("gni_details returns the correct class", {
