@@ -3,22 +3,28 @@ context("iucn_summary")
 
 test_that("iucn_summary returns the correct value", {
   skip_on_cran()
-
+  if (is.na(getkey(NA, service = "iucn"))) {
+    skip("No IUCN api key so test not run.")
+  }
+  
   temp <- iucn_summary(c("Panthera uncia", "Lynx lynx"))
-  temp2 <- iucn_summary_id(c(22732, 12519))
+  temp2 <- suppressWarnings(iucn_summary_id(c(22732, 12519)))
 
   expect_that(length(temp[[1]]), equals(4))
 
-  expect_that(temp, is_a("iucn"))
+  expect_is(temp, "iucn_summary")
 
-  expect_identical(temp, temp2)
+  #expect_equal(temp, temp2)
 
-  expect_that(length(iucn_status(temp)), equals(2))
+  expect_equal(length(iucn_status(temp)), 2)
 })
 
 test_that("iucn_summary gives expected result for lots of names", {
   skip_on_cran()
-
+  if (is.na(getkey(NA, service = "iucn"))) {
+    skip("No IUCN api key so test not run.")
+  }
+  
   aa <- iucn_summary("Abies koreana")
   expect_equal(aa$`Abies koreana`$status, "EN")
 
@@ -46,18 +52,24 @@ test_that("iucn_summary gives expected result for lots of names", {
 
 test_that("iucn_summary_id with distr_detail produces correct output", {
   skip_on_cran()
-
-  ii <- iucn_summary_id(22685566, distr_detail = TRUE)
-  expect_equal(names(ii$`Ara chloropterus`$distr), c("Native", "Introduced"))
-  expect_equal(vapply(ii$`Ara chloropterus`$distr, length, 0),
+  if (is.na(getkey(NA, service = "iucn"))) {
+    skip("No IUCN api key so test not run.")
+  }
+  
+  ii <- suppressWarnings(iucn_summary_id(22685566, distr_detail = TRUE))
+  expect_equal(names(ii$`22685566`$distr), c("Native", "Introduced"))
+  expect_equal(vapply(ii$`22685566`$distr, length, 0),
                c(Native = 12, Introduced = 1))
 })
 
 test_that("iucn_summary and iucn_summary_id fail well", {
   skip_on_cran()
-
-  expect_warning(iucn_summary(""), "not found")
-  expect_equal(suppressWarnings(iucn_summary(""))[[1]]$status, NA)
+  if (is.na(getkey(NA, service = "iucn"))) {
+    skip("No IUCN api key so test not run.")
+  }
+  
+  expect_error(iucn_summary(""), "Not Found")
+  #expect_equal(suppressWarnings(iucn_summary(""))[[1]]$status, NA)
   expect_warning(iucn_summary("Abies"), "not found")
   expect_warning(iucn_summary_id(0), "not found")
   expect_equal(suppressWarnings(iucn_summary_id(0))[[1]]$status, NA)
